#' @importFrom ggplot2 ggplot
#' @export
ggplot2::ggplot

#' @importFrom ggplot2 ggtitle
#' @export
ggplot2::ggtitle

#' @importFrom ggplot2 guides
#' @export
ggplot2::guides

#' @importFrom ggplot2 labs
#' @export
ggplot2::labs

#' @importFrom ggplot2 xlab
#' @export
ggplot2::xlab

#' @importFrom ggplot2 ylab
#' @export
ggplot2::ylab

#' @importFrom ggplot2 aes
#' @export
ggplot2::aes

#' @importFrom ggplot2 ggsave
#' @export
ggplot2::ggsave

#' @importFrom ggplot2 scale_y_discrete
#' @export
ggplot2::scale_y_discrete

